@@ -40,8 +40,8 @@ class Server:
         self.elems = {}
         self.rows = 20
         self.columns = 80
-        self.getTerminalSize()
         self.lastRefresh = 0
+        self.getTerminalSize()
 
     def start(self):
         self._p = Process(target=_screenMainLoop, args=(self,))
@@ -59,7 +59,7 @@ class Server:
         self.elems[elem_id] = element
         return line(self.q, elem_id, element.variables)
 
-    def _getElem(self, elem):
+    def getElem(self, elem):
         if elem in self.elems:
             return self.elems[elem]
         return None
